# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from tarot import bots_master_pb2 as tarot_dot_bots__master__pb2


class BotsMasterStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.RetrieveBots = channel.unary_unary(
                '/tarot.BotsMaster/RetrieveBots',
                request_serializer=tarot_dot_bots__master__pb2.RetrieveBotsRequest.SerializeToString,
                response_deserializer=tarot_dot_bots__master__pb2.RetrieveBotsResponse.FromString,
                )
        self.RetrieveBot = channel.unary_unary(
                '/tarot.BotsMaster/RetrieveBot',
                request_serializer=tarot_dot_bots__master__pb2.RetrieveBotRequest.SerializeToString,
                response_deserializer=tarot_dot_bots__master__pb2.Bot.FromString,
                )


class BotsMasterServicer(object):
    """Missing associated documentation comment in .proto file."""

    def RetrieveBots(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RetrieveBot(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_BotsMasterServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'RetrieveBots': grpc.unary_unary_rpc_method_handler(
                    servicer.RetrieveBots,
                    request_deserializer=tarot_dot_bots__master__pb2.RetrieveBotsRequest.FromString,
                    response_serializer=tarot_dot_bots__master__pb2.RetrieveBotsResponse.SerializeToString,
            ),
            'RetrieveBot': grpc.unary_unary_rpc_method_handler(
                    servicer.RetrieveBot,
                    request_deserializer=tarot_dot_bots__master__pb2.RetrieveBotRequest.FromString,
                    response_serializer=tarot_dot_bots__master__pb2.Bot.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'tarot.BotsMaster', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class BotsMaster(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def RetrieveBots(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/tarot.BotsMaster/RetrieveBots',
            tarot_dot_bots__master__pb2.RetrieveBotsRequest.SerializeToString,
            tarot_dot_bots__master__pb2.RetrieveBotsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def RetrieveBot(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/tarot.BotsMaster/RetrieveBot',
            tarot_dot_bots__master__pb2.RetrieveBotRequest.SerializeToString,
            tarot_dot_bots__master__pb2.Bot.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
